pub struct Ray<T: Scalar, V: Vector<T>> {
pub start: V,
pub direction: V,
/* private fields */
}Expand description
A ray with an origin and direction.
Commonly used for ray casting and intersection tests.
Fields
start: VRay origin.
direction: VRay direction (typically normalized).
Implementations
Sourceimpl<T: FloatScalar, V: FloatVector<T>> Ray<T, V>
impl<T: FloatScalar, V: FloatVector<T>> Ray<T, V>
Sourceimpl<T: FloatScalar> Ray<T, Vector3<T>>
impl<T: FloatScalar> Ray<T, Vector3<T>>
Sourcepub fn intersect_plane(&self, p: &Plane<T>, epsilon: T) -> Option<Vector3<T>>
pub fn intersect_plane(&self, p: &Plane<T>, epsilon: T) -> Option<Vector3<T>>
Computes ray-plane intersection.
Returns the intersection point, or None if the ray doesn’t hit the plane
(parallel or pointing away).
Returns None if the ray is parallel to the plane within epsilon.